==> pyasic-0.48.1.tar.gz: pyasic-0.48.1/pyasic/miners/whatsminer/btminer/M3X/M30S_Plus.py <==
# ------------------------------------------------------------------------------
#  Copyright 2022 Upstream Data Inc                                            -
#                                                                              -
#  Licensed under the Apache License, Version 2.0 (the "License");             -
#  you may not use this file except in compliance with the License.            -
#  You may obtain a copy of the License at                                     -
#                                                                              -
#      http://www.apache.org/licenses/LICENSE-2.0                              -
#                                                                              -
#  Unless required by applicable law or agreed to in writing, software         -
#  distributed under the License is distributed on an "AS IS" BASIS,           -
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.    -
#  See the License for the specific language governing permissions and         -
#  limitations under the License.                                              -
# ------------------------------------------------------------------------------

from pyasic.miners.backends import M3X
from pyasic.miners.types import (
    M30SPlusV10,
    M30SPlusV20,
    M30SPlusV30,
    M30SPlusV40,
    M30SPlusV50,
    M30SPlusV60,
    M30SPlusV70,
    M30SPlusV80,
    M30SPlusV90,
    M30SPlusV100,
    M30SPlusVE30,
    M30SPlusVE40,
    M30SPlusVE50,
    M30SPlusVE60,
    M30SPlusVE70,
    M30SPlusVE80,
    M30SPlusVE90,
    M30SPlusVE100,
    M30SPlusVF20,
    M30SPlusVF30,
    M30SPlusVG20,
    M30SPlusVG30,
    M30SPlusVG40,
    M30SPlusVG50,
    M30SPlusVG60,
    M30SPlusVH10,
    M30SPlusVH20,
    M30SPlusVH30,
    M30SPlusVH40,
    M30SPlusVH50,
    M30SPlusVH60,
)


class BTMinerM30SPlusV10(M3X, M30SPlusV10):
    pass


class BTMinerM30SPlusV20(M3X, M30SPlusV20):
    pass


class BTMinerM30SPlusV30(M3X, M30SPlusV30):
    pass


class BTMinerM30SPlusV40(M3X, M30SPlusV40):
    pass


class BTMinerM30SPlusV50(M3X, M30SPlusV50):
    pass


class BTMinerM30SPlusV60(M3X, M30SPlusV60):
    pass


class BTMinerM30SPlusV70(M3X, M30SPlusV70):
    pass


class BTMinerM30SPlusV80(M3X, M30SPlusV80):
    pass


class BTMinerM30SPlusV90(M3X, M30SPlusV90):
    pass


class BTMinerM30SPlusV100(M3X, M30SPlusV100):
    pass


class BTMinerM30SPlusVE30(M3X, M30SPlusVE30):
    pass


class BTMinerM30SPlusVE40(M3X, M30SPlusVE40):
    pass


class BTMinerM30SPlusVE50(M3X, M30SPlusVE50):
    pass


class BTMinerM30SPlusVE60(M3X, M30SPlusVE60):
    pass


class BTMinerM30SPlusVE70(M3X, M30SPlusVE70):
    pass


class BTMinerM30SPlusVE80(M3X, M30SPlusVE80):
    pass


class BTMinerM30SPlusVE90(M3X, M30SPlusVE90):
    pass


class BTMinerM30SPlusVE100(M3X, M30SPlusVE100):
    pass


class BTMinerM30SPlusVF20(M3X, M30SPlusVF20):
    pass


class BTMinerM30SPlusVF30(M3X, M30SPlusVF30):
    pass


class BTMinerM30SPlusVG20(M3X, M30SPlusVG20):
    pass


class BTMinerM30SPlusVG30(M3X, M30SPlusVG30):
    pass


class BTMinerM30SPlusVG40(M3X, M30SPlusVG40):
    pass


class BTMinerM30SPlusVG50(M3X, M30SPlusVG50):
    pass


class BTMinerM30SPlusVG60(M3X, M30SPlusVG60):
    pass


class BTMinerM30SPlusVH10(M3X, M30SPlusVH10):
    pass


class BTMinerM30SPlusVH20(M3X, M30SPlusVH20):
    pass


class BTMinerM30SPlusVH30(M3X, M30SPlusVH30):
    pass


class BTMinerM30SPlusVH40(M3X, M30SPlusVH40):
    pass


class BTMinerM30SPlusVH50(M3X, M30SPlusVH50):
    pass


class BTMinerM30SPlusVH60(M3X, M30SPlusVH60):
    pass

==> pyasic-0.64.1.tar.gz: pyasic-0.64.1/pyasic/miners/whatsminer/btminer/M3X/M30S_Plus.py <==
# ------------------------------------------------------------------------------
#  Copyright 2022 Upstream Data Inc                                            -
#                                                                              -
#  Licensed under the Apache License, Version 2.0 (the "License");             -
#  you may not use this file except in compliance with the License.            -
#  You may obtain a copy of the License at                                     -
#                                                                              -
#      http://www.apache.org/licenses/LICENSE-2.0                              -
#                                                                              -
#  Unless required by applicable law or agreed to in writing, software         -
#  distributed under the License is distributed on an "AS IS" BASIS,           -
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.    -
#  See the License for the specific language governing permissions and         -
#  limitations under the License.                                              -
# ------------------------------------------------------------------------------

from pyasic.miners.backends import M3X
from pyasic.miners.device.models import (
    M30SPlusV10,
    M30SPlusV20,
    M30SPlusV30,
    M30SPlusV40,
    M30SPlusV50,
    M30SPlusV60,
    M30SPlusV70,
    M30SPlusV80,
    M30SPlusV90,
    M30SPlusV100,
    M30SPlusVE30,
    M30SPlusVE40,
    M30SPlusVE50,
    M30SPlusVE60,
    M30SPlusVE70,
    M30SPlusVE80,
    M30SPlusVE90,
    M30SPlusVE100,
    M30SPlusVF20,
    M30SPlusVF30,
    M30SPlusVG20,
    M30SPlusVG30,
    M30SPlusVG40,
    M30SPlusVG50,
    M30SPlusVG60,
    M30SPlusVH10,
    M30SPlusVH20,
    M30SPlusVH30,
    M30SPlusVH40,
    M30SPlusVH50,
    M30SPlusVH60,
)


class BTMinerM30SPlusV10(M3X, M30SPlusV10):
    pass


class BTMinerM30SPlusV20(M3X, M30SPlusV20):
    pass


class BTMinerM30SPlusV30(M3X, M30SPlusV30):
    pass


class BTMinerM30SPlusV40(M3X, M30SPlusV40):
    pass


class BTMinerM30SPlusV50(M3X, M30SPlusV50):
    pass


class BTMinerM30SPlusV60(M3X, M30SPlusV60):
    pass


class BTMinerM30SPlusV70(M3X, M30SPlusV70):
    pass


class BTMinerM30SPlusV80(M3X, M30SPlusV80):
    pass


class BTMinerM30SPlusV90(M3X, M30SPlusV90):
    pass


class BTMinerM30SPlusV100(M3X, M30SPlusV100):
    pass


class BTMinerM30SPlusVE30(M3X, M30SPlusVE30):
    pass


class BTMinerM30SPlusVE40(M3X, M30SPlusVE40):
    pass


class BTMinerM30SPlusVE50(M3X, M30SPlusVE50):
    pass


class BTMinerM30SPlusVE60(M3X, M30SPlusVE60):
    pass


class BTMinerM30SPlusVE70(M3X, M30SPlusVE70):
    pass


class BTMinerM30SPlusVE80(M3X, M30SPlusVE80):
    pass


class BTMinerM30SPlusVE90(M3X, M30SPlusVE90):
    pass


class BTMinerM30SPlusVE100(M3X, M30SPlusVE100):
    pass


class BTMinerM30SPlusVF20(M3X, M30SPlusVF20):
    pass


class BTMinerM30SPlusVF30(M3X, M30SPlusVF30):
    pass


class BTMinerM30SPlusVG20(M3X, M30SPlusVG20):
    pass


class BTMinerM30SPlusVG30(M3X, M30SPlusVG30):
    pass


class BTMinerM30SPlusVG40(M3X, M30SPlusVG40):
    pass


class BTMinerM30SPlusVG50(M3X, M30SPlusVG50):
    pass


class BTMinerM30SPlusVG60(M3X, M30SPlusVG60):
    pass


class BTMinerM30SPlusVH10(M3X, M30SPlusVH10):
    pass


class BTMinerM30SPlusVH20(M3X, M30SPlusVH20):
    pass


class BTMinerM30SPlusVH30(M3X, M30SPlusVH30):
    pass


class BTMinerM30SPlusVH40(M3X, M30SPlusVH40):
    pass


class BTMinerM30SPlusVH50(M3X, M30SPlusVH50):
    pass


class BTMinerM30SPlusVH60(M3X, M30SPlusVH60):
    pass
